@@ -31,11 +31,12 @@
 	<depend>iksemel</depend>
 	<depend>res_jabber</depend>
 	<use>openssl</use>
+	<support_level>extended</support_level>
  ***/
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 291758 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 328446 $")
 
 #include <sys/socket.h>
 #include <fcntl.h>
@@ -584,7 +585,6 @@ static int jingle_create_candidates(struct jingle *client, struct jingle_pvt *p,
 	struct ast_sockaddr sin_tmp;
 	struct ast_sockaddr us_tmp;
 	struct ast_sockaddr bindaddr_tmp;
-	struct sockaddr_in dest;
 	struct in_addr us;
 	struct in_addr externaddr;
 	iks *iq, *jingle, *content, *transport, *candidate;
@@ -665,9 +665,6 @@ static int jingle_create_candidates(struct jingle *client, struct jingle_pvt *p,
 		ours2 = NULL;
 	}
 	ours1 = NULL;
-	dest.sin_addr = __ourip;
-	dest.sin_port = sin.sin_port;
-
 
 	for (tmp = p->ourcandidates; tmp; tmp = tmp->next) {
 		snprintf(component, sizeof(component), "%u", tmp->component);
