@@ -27,11 +27,12 @@
 
 /*** MODULEINFO
 	<depend>ixjuser</depend>
+	<support_level>extended</support_level>
  ***/
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 284597 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 328209 $")
 
 #include <ctype.h>
 #include <sys/socket.h>
@@ -296,12 +297,10 @@ static int phone_call(struct ast_channel *ast, char *dest, int timeout)
 	ast_localtime(&UtcTime, &tm, NULL);
 
 	memset(&cid, 0, sizeof(PHONE_CID));
-	if(&tm != NULL) {
-		snprintf(cid.month, sizeof(cid.month), "%02d",(tm.tm_mon + 1));
-		snprintf(cid.day, sizeof(cid.day),     "%02d", tm.tm_mday);
-		snprintf(cid.hour, sizeof(cid.hour),   "%02d", tm.tm_hour);
-		snprintf(cid.min, sizeof(cid.min),     "%02d", tm.tm_min);
-	}
+    snprintf(cid.month, sizeof(cid.month), "%02d",(tm.tm_mon + 1));
+    snprintf(cid.day, sizeof(cid.day),     "%02d", tm.tm_mday);
+    snprintf(cid.hour, sizeof(cid.hour),   "%02d", tm.tm_hour);
+    snprintf(cid.min, sizeof(cid.min),     "%02d", tm.tm_min);
 	/* the standard format of ast->callerid is:  "name" <number>, but not always complete */
 	if (!ast->connected.id.name.valid
 		|| ast_strlen_zero(ast->connected.id.name.str)) {
