@@ -21,7 +21,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 324704 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 324685 $")
 
 #include "include/sip.h"
 #include "include/sip_utils.h"
@@ -1157,7 +1157,7 @@ int parse_name_andor_addr(char *uri, const char *scheme, char **name,
 			  struct uriparams *params, char **headers,
 			  char **residue)
 {
-	static char buf[1024];
+	char buf[1024];
 	char **residue2=residue;
 	int ret;
 	if (name) {
@@ -2038,7 +2038,11 @@ static int sip_uri_domain_cmp(const char *host1, const char *host2)
 	 */
 	if (!addr1_parsed) {
 #ifdef HAVE_XLOCALE_H
-		return strcasecmp_l(host1, host2, c_locale);
+		if(!c_locale) {
+			return strcasecmp(host1, host2);
+		} else {
+			return strcasecmp_l(host1, host2, c_locale);
+		}
 #else
 		return strcasecmp(host1, host2);
 #endif
