@@ -24,9 +24,13 @@
  * \ingroup formats
  */
  
+/*** MODULEINFO
+	<support_level>core</support_level>
+ ***/
+
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 284701 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 330213 $")
 
 #include "asterisk/mod_format.h"
 #include "asterisk/module.h"
@@ -71,48 +75,12 @@ struct wav_desc {	/* format-specific parameters */
 #endif
 
 
-static int check_header(FILE *f, int hz)
+static int check_header_fmt(FILE *f, int hsize, int hz)
 {
-	int type, size, formtype;
-	int fmt, hsize;
 	short format, chans, bysam, bisam;
 	int bysec;
 	int freq;
-	int data;
-	if (fread(&type, 1, 4, f) != 4) {
-		ast_log(LOG_WARNING, "Read failed (type)\n");
-		return -1;
-	}
-	if (fread(&size, 1, 4, f) != 4) {
-		ast_log(LOG_WARNING, "Read failed (size)\n");
-		return -1;
-	}
-	size = ltohl(size);
-	if (fread(&formtype, 1, 4, f) != 4) {
-		ast_log(LOG_WARNING, "Read failed (formtype)\n");
-		return -1;
-	}
-	if (memcmp(&type, "RIFF", 4)) {
-		ast_log(LOG_WARNING, "Does not begin with RIFF\n");
-		return -1;
-	}
-	if (memcmp(&formtype, "WAVE", 4)) {
-		ast_log(LOG_WARNING, "Does not contain WAVE\n");
-		return -1;
-	}
-	if (fread(&fmt, 1, 4, f) != 4) {
-		ast_log(LOG_WARNING, "Read failed (fmt)\n");
-		return -1;
-	}
-	if (memcmp(&fmt, "fmt ", 4)) {
-		ast_log(LOG_WARNING, "Does not say fmt\n");
-		return -1;
-	}
-	if (fread(&hsize, 1, 4, f) != 4) {
-		ast_log(LOG_WARNING, "Read failed (formtype)\n");
-		return -1;
-	}
-	if (ltohl(hsize) < 16) {
+	if (hsize < 16) {
 		ast_log(LOG_WARNING, "Unexpected header size %d\n", ltohl(hsize));
 		return -1;
 	}
@@ -165,6 +133,34 @@ static int check_header(FILE *f, int hz)
 		ast_log(LOG_WARNING, "Failed to skip remaining header bytes: %d\n", ltohl(hsize)-16 );
 		return -1;
 	}
+	return 0;
+}
+
+static int check_header(FILE *f, int hz)
+{
+	int type, size, formtype;
+	int data;
+	if (fread(&type, 1, 4, f) != 4) {
+		ast_log(LOG_WARNING, "Read failed (type)\n");
+		return -1;
+	}
+	if (fread(&size, 1, 4, f) != 4) {
+		ast_log(LOG_WARNING, "Read failed (size)\n");
+		return -1;
+	}
+	size = ltohl(size);
+	if (fread(&formtype, 1, 4, f) != 4) {
+		ast_log(LOG_WARNING, "Read failed (formtype)\n");
+		return -1;
+	}
+	if (memcmp(&type, "RIFF", 4)) {
+		ast_log(LOG_WARNING, "Does not begin with RIFF\n");
+		return -1;
+	}
+	if (memcmp(&formtype, "WAVE", 4)) {
+		ast_log(LOG_WARNING, "Does not contain WAVE\n");
+		return -1;
+	}
 	/* Skip any facts and get the first data block */
 	for(;;)
 	{ 
@@ -172,23 +168,25 @@ static int check_header(FILE *f, int hz)
 	    
 	    /* Begin data chunk */
 	    if (fread(&buf, 1, 4, f) != 4) {
-			ast_log(LOG_WARNING, "Read failed (data)\n");
+			ast_log(LOG_WARNING, "Read failed (block header format)\n");
 			return -1;
 	    }
 	    /* Data has the actual length of data in it */
 	    if (fread(&data, 1, 4, f) != 4) {
-			ast_log(LOG_WARNING, "Read failed (data)\n");
+			ast_log(LOG_WARNING, "Read failed (block '%.4s' header length)\n", buf);
 			return -1;
 	    }
 	    data = ltohl(data);
+		if (memcmp(&buf, "fmt ", 4) == 0) {
+			if (check_header_fmt(f, data, hz))
+				return -1;
+			continue;
+		}
 	    if(memcmp(buf, "data", 4) == 0 ) 
 			break;
-	    if(memcmp(buf, "fact", 4) != 0 ) {
-			ast_log(LOG_WARNING, "Unknown block - not fact or data\n");
-			return -1;
-	    }
+		ast_log(LOG_DEBUG, "Skipping unknown block '%.4s'\n", buf);
 	    if (fseek(f,data,SEEK_CUR) == -1 ) {
-			ast_log(LOG_WARNING, "Failed to skip fact block: %d\n", data );
+			ast_log(LOG_WARNING, "Failed to skip '%.4s' block: %d\n", buf, data);
 			return -1;
 	    }
 	}
@@ -342,6 +340,10 @@ static void wav_close(struct ast_filestream *s)
 	char zero = 0;
 	struct wav_desc *fs = (struct wav_desc *)s->_private;
 
+	if (s->mode == O_RDONLY) {
+		return;
+	}
+
 	if (s->filename) {
 		update_header(s->f);
 	}
@@ -360,8 +362,8 @@ static struct ast_frame *wav_read(struct ast_filestream *s, int *whennext)
 	int samples;	/* actual samples read */
 #if __BYTE_ORDER == __BIG_ENDIAN
 	int x;
-#endif
 	short *tmp;
+#endif
 	int bytes;
 	off_t here;
 	/* Send a frame from the file to the appropriate channel */
@@ -388,8 +390,8 @@ static struct ast_frame *wav_read(struct ast_filestream *s, int *whennext)
 	s->fr.datalen = res;
 	s->fr.samples = samples = res / 2;
 
-	tmp = (short *)(s->fr.data.ptr);
 #if __BYTE_ORDER == __BIG_ENDIAN
+	tmp = (short *)(s->fr.data.ptr);
 	/* file format is little endian so we need to swap */
 	for( x = 0; x < samples; x++)
 		tmp[x] = (tmp[x] << 8) | ((tmp[x] & 0xff00) >> 8);
