@@ -27,7 +27,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 331649 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 337973 $")
 
 /* When we include logger.h again it will trample on some stuff in syslog.h, but
  * nothing we care about in here. */
@@ -646,12 +646,15 @@ static int rotate_file(const char *filename)
 	if (!ast_strlen_zero(exec_after_rotate)) {
 		struct ast_channel *c = ast_dummy_channel_alloc();
 		char buf[512];
+
 		pbx_builtin_setvar_helper(c, "filename", filename);
 		pbx_substitute_variables_helper(c, exec_after_rotate, buf, sizeof(buf));
+		if (c) {
+			c = ast_channel_unref(c);
+		}
 		if (ast_safe_system(buf) == -1) {
 			ast_log(LOG_WARNING, "error executing '%s'\n", buf);
 		}
-		c = ast_channel_release(c);
 	}
 	return res;
 }
@@ -1661,7 +1664,7 @@ void ast_logger_unregister_level(const char *name)
 
 		global_logmask &= ~(1 << x);
 
-		free(levels[x]);
+		ast_free(levels[x]);
 		levels[x] = NULL;
 		AST_RWLIST_UNLOCK(&logchannels);
 
