@@ -24,9 +24,13 @@
  *
  */
 
+/*** MODULEINFO
+	<support_level>core</support_level>
+ ***/
+
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 196758 $");
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 328209 $");
 
 #include "asterisk/channel.h"
 #include "asterisk/pbx.h"
